from pathlib import Path
from functools import partial
from typing import Callable
import logging

from jgutils.filesystem import get_files_recursive

logger = logging.getLogger(__name__)


def _get_converted_path(input_path: Path,
                        output_dir: Path,
                        output_ext: str):
    """
    Return the path you would obtain if you moved the file in the input
    path to the output directory in the config and changed its extension.
    """

    output_filename = str(input_path.stem) + f".{output_ext}"
    return output_dir / input_path.parent / output_filename

def convert(input_dir: Path,
            output_dir: Path,
            input_ext: str,
            output_ext: str,
            conversion_func: Callable):

    logger.info("Converting files in %s to %s", input_dir, output_dir)

    input_files = get_files_recursive(input_dir.resolve(), [input_ext])
    output_files = [_get_converted_path(f.relative_to(input_dir),
                                        output_dir,
                                        output_ext) for f in input_files]
    conversion_pairs = [io_paths for io_paths in
            zip(input_files, output_files) if not io_paths[1].exists()]

    run_tasks(conversion_func, conversion_pairs)
